@@ -8,12 +8,12 @@
 #
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::Compile; # git description: v2.054-18-gc83214d
+package Dist::Zilla::Plugin::Test::Compile; # git description: v2.056-4-g5817fa6
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Common tests to check syntax of your modules, using only core modules
 # KEYWORDS: plugin test compile verify validate load modules scripts
 
-our $VERSION = '2.055';
+our $VERSION = '2.057';
 
 use Moose;
 use Path::Tiny;
@@ -385,7 +385,7 @@ Dist::Zilla::Plugin::Test::Compile - Common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.055
+version 2.057
 
 =head1 SYNOPSIS
 
@@ -691,7 +691,8 @@ for my $lib (@module_files)
     # see L<perlfaq8/How can I capture STDERR from an external command?>
     my $stderr = IO::Handle->new;
 
-    diag('Running: ', join(', ', $^X, @switches, '-e\'', "require q[$lib]", '\''))
+    diag('Running: ', join(', ', map { my $str = $_; $str =~ s/'/\\'/g; q{'} . $str . q{'} }
+            $^X, @switches, '-e', "require q[$lib]"))
         if $ENV{PERL_COMPILE_TEST_DEBUG};
 
     my $pid = open3($stdin, '>&STDERR', $stderr, $^X, @switches, '-e', "require q[$lib]");
@@ -701,7 +702,7 @@ for my $lib (@module_files)
     is($?, 0, "$lib loaded ok");
 
     shift @_warnings if @_warnings and $_warnings[0] =~ /^Using .*\bblib/
-        and not eval { require blib; blib->VERSION('1.01') };
+        and not eval { +require blib; blib->VERSION('1.01') };
 
     if (@_warnings)
     {
@@ -722,7 +723,8 @@ foreach my $file (@scripts)
 
     my $stderr = IO::Handle->new;
 
-    diag('Running: ', join(', ', $^X, @switches, '-c', $file))
+    diag('Running: ', join(', ', map { my $str = $_; $str =~ s/'/\\'/g; q{'} . $str . q{'} }
+            $^X, @switches, '-c', $file))
         if $ENV{PERL_COMPILE_TEST_DEBUG};
 
     my $pid = open3($stdin, '>&STDERR', $stderr, $^X, @switches, '-c', $file);
@@ -732,7 +734,7 @@ foreach my $file (@scripts)
     is($?, 0, "$file compiled ok");
 
     shift @_warnings if @_warnings and $_warnings[0] =~ /^Using .*\bblib/
-        and not eval { require blib; blib->VERSION('1.01') };
+        and not eval { +require blib; blib->VERSION('1.01') };
 
     # in older perls, -c output is simply the file portion of the path being tested
     if (@_warnings = grep { !/\bsyntax OK$/ }
